@@ -16,9 +16,16 @@ THEME_NAME=Qogir
 THEME_VARIANTS=('' '-manjaro' '-ubuntu')
 WIN_VARIANTS=('' '-win')
 COLOR_VARIANTS=('' '-light' '-dark')
-LOGO_VARIANTS=('' '-arch' '-budgie' '-debian' '-fedora' '-gnome' '-gentoo' '-manjaro' '-ubuntu' '-qogir')
 LOGO_NAME=''
 
+image=''
+window=''
+square=''
+
+theme_color='default'
+
+SASSC_OPT="-M -t expanded"
+
 if [[ "$(command -v gnome-shell)" ]]; then
   SHELL_VERSION="$(gnome-shell --version | cut -d ' ' -f 3 | cut -d . -f -1)"
   echo "Your gnome-shell version is '$(gnome-shell --version)'"
@@ -33,35 +40,49 @@ if [[ "$(command -v gnome-shell)" ]]; then
 fi
 
 usage() {
-  printf "%s\n" "Usage: $0 [OPTIONS...]"
-  printf "\n%s\n" "OPTIONS:"
-  printf "  %-25s%s\n" "-d, --dest DIR" "Specify theme destination directory (Default: ${DEST_DIR})"
-  printf "  %-25s%s\n" "-n, --name NAME" "Specify theme name (Default: ${THEME_NAME})"
-  printf "  %-25s%s\n" "-l, --logo VARIANTS" "Specify nautilus logo [arch|budgie|debian|fedora|gnome|gentoo|manjaro|ubuntu] (Default: qogir icon)"
-  printf "  %-25s%s\n" "-w, --win VARIANTS..." "Specify titlebutton variant(s) [standard|square] (Default: All variants)"
-  printf "  %-25s%s\n" "-t, --theme VARIANTS..." "Specify theme primary color variant(s) [standard|manjaro|ubuntu] (Default: All variants)"
-  printf "  %-25s%s\n" "-c, --color VARIANTS..." "Specify theme color variant(s) [standard|light|dark] (Default: All variants)"
-  printf "  %-25s%s\n" "-i, --image VARIANTS..." "Install theme with nautilus background image"
-  printf "  %-25s%s\n" "-g, --gdm" "Install GDM theme, this option need root user authority! please run this with sudo"
-  printf "  %-25s%s\n" "-r, --revert" "revert GDM theme, this option need root user authority! please run this with sudo"
-  printf "  %-25s%s\n" "-h, --help" "Show this help"
+cat << EOF
+Usage: $0 [OPTION]...
+
+OPTIONS:
+  -d, --dest DIR          Specify destination directory (Default: $DEST_DIR)
+
+  -n, --name NAME         Specify theme name (Default: $THEME_NAME)
+
+  -t, --theme VARIANT     Specify theme primary color variant(s) [default|manjaro|ubuntu|all] (Default: blue color)
+
+  -c, --color VARIANT     Specify theme color variant(s) [standard|light|dark] (Default: All variants)
+
+  -l, --logo VARIANT      Specify logo icon on nautilus [default|manjaro|ubuntu|fedora|debian|arch|gnome|budgie|popos] (Default: mountain icon)
+
+  -g, --gdm               Install GDM theme, this option need root user authority! please run this with sudo
+
+  -r, --revert            revert GDM theme, this option need root user authority! please run this with sudo
+
+  --tweaks                Specify versions for tweaks [image|square|round] (options can mix use)
+                          1. image:    Install with a background image on (Nautilus/Nemo)
+                          2. square:   Install square window button like Windows 10
+                          3. round:    Install rounded window and popup/menu version
+
+  -h, --help              Show help
+EOF
 }
 
 install() {
   local dest=${1}
   local name=${2}
   local theme=${3}
-  local win=${4}
-  local color=${5}
-  local logo=${6}
+  local color=${4}
+  local logo=${5}
 
   [[ ${color} == '-dark' ]] && local ELSE_DARK=${color}
   [[ ${color} == '-light' ]] && local ELSE_LIGHT=${color}
 
-  local THEME_DIR=${dest}/${name}${theme}${win}${color}
+  local THEME_DIR=${dest}/${name}${theme}${color}
 
   [[ -d ${THEME_DIR} ]] && rm -rf ${THEME_DIR}
 
+  theme_tweaks && install_theme_color
+
   echo "Installing '${THEME_DIR}'..."
 
   mkdir -p                                                                           ${THEME_DIR}
@@ -70,23 +91,25 @@ install() {
 
   echo "[Desktop Entry]"                                                          >> ${THEME_DIR}/index.theme
   echo "Type=X-GNOME-Metatheme"                                                   >> ${THEME_DIR}/index.theme
-  echo "Name=${name}${theme}${win}${color}"                                       >> ${THEME_DIR}/index.theme
+  echo "Name=${name}${theme}${color}"                                             >> ${THEME_DIR}/index.theme
   echo "Comment=An Clean Gtk+ theme based on Flat Design"                         >> ${THEME_DIR}/index.theme
   echo "Encoding=UTF-8"                                                           >> ${THEME_DIR}/index.theme
   echo ""                                                                         >> ${THEME_DIR}/index.theme
   echo "[X-GNOME-Metatheme]"                                                      >> ${THEME_DIR}/index.theme
-  echo "GtkTheme=${name}${theme}${win}${color}"                                   >> ${THEME_DIR}/index.theme
-  echo "MetacityTheme=${name}${theme}${win}${color}"                              >> ${THEME_DIR}/index.theme
+  echo "GtkTheme=${name}${theme}${color}"                                         >> ${THEME_DIR}/index.theme
+  echo "MetacityTheme=${name}${theme}${color}"                                    >> ${THEME_DIR}/index.theme
   echo "IconTheme=${name}${theme}${ELSE_DARK}"                                    >> ${THEME_DIR}/index.theme
   echo "CursorTheme=Adwaita"                                                      >> ${THEME_DIR}/index.theme
   echo "ButtonLayout=menu:minimize,maximize,close"                                >> ${THEME_DIR}/index.theme
 
+  # GTK 2.0
   mkdir -p                                                                           ${THEME_DIR}/gtk-2.0
   cp -r ${SRC_DIR}/src/gtk-2.0/{apps.rc,panel.rc,main.rc,xfce-notify.rc}             ${THEME_DIR}/gtk-2.0
   cp -r ${SRC_DIR}/src/gtk-2.0/assets/assets${theme}${ELSE_DARK}                     ${THEME_DIR}/gtk-2.0/assets
   cp -r ${SRC_DIR}/src/gtk-2.0/theme${theme}/gtkrc${color}                           ${THEME_DIR}/gtk-2.0/gtkrc
   cp -r ${SRC_DIR}/src/gtk-2.0/menubar-toolbar${color}.rc                            ${THEME_DIR}/gtk-2.0/menubar-toolbar.rc
 
+  # GTK 3.0
   mkdir -p                                                                           ${THEME_DIR}/gtk-3.0
   cp -r ${SRC_DIR}/src/gtk/assets/assets${theme}                                     ${THEME_DIR}/gtk-3.0/assets
 
@@ -100,11 +123,24 @@ install() {
   fi
 
   cp -r ${SRC_DIR}/src/gtk/assets/assets-common/*                                    ${THEME_DIR}/gtk-3.0/assets
-  cp -r ${SRC_DIR}/src/gtk/theme${theme}-3.0/gtk${win}${color}.css                   ${THEME_DIR}/gtk-3.0/gtk.css
-  [[ ${color} != '-dark' ]] && \
-  cp -r ${SRC_DIR}/src/gtk/theme${theme}-3.0/gtk${win}-dark.css                      ${THEME_DIR}/gtk-3.0/gtk-dark.css
+
+  if [[ "$tweaks" == 'true' ]]; then
+    sassc $SASSC_OPT ${SRC_DIR}/src/gtk/theme-3.0/gtk${color}.scss                   ${THEME_DIR}/gtk-3.0/gtk.css
+  else
+    cp -r ${SRC_DIR}/src/gtk/theme-3.0/gtk${color}.css                               ${THEME_DIR}/gtk-3.0/gtk.css
+  fi
+
+  if [[ ${color} != '-dark' ]]; then
+    if [[ "$tweaks" == 'true' ]]; then
+      sassc $SASSC_OPT ${SRC_DIR}/src/gtk/theme-3.0/gtk-dark.scss                    ${THEME_DIR}/gtk-3.0/gtk-dark.css
+    else
+      cp -r ${SRC_DIR}/src/gtk/theme-3.0/gtk-dark.css                                ${THEME_DIR}/gtk-3.0/gtk-dark.css
+    fi
+  fi
+
   cp -r ${SRC_DIR}/src/gtk/assets/thumbnail${theme}${ELSE_DARK}.png                  ${THEME_DIR}/gtk-3.0/thumbnail.png
 
+  # GTK 4.0
   mkdir -p                                                                           ${THEME_DIR}/gtk-4.0
   cp -r ${SRC_DIR}/src/gtk/assets/assets${theme}                                     ${THEME_DIR}/gtk-4.0/assets
 
@@ -118,16 +154,28 @@ install() {
   fi
 
   cp -r ${SRC_DIR}/src/gtk/assets/assets-common/*                                    ${THEME_DIR}/gtk-4.0/assets
-  cp -r ${SRC_DIR}/src/gtk/theme${theme}-4.0/gtk${win}${color}.css                   ${THEME_DIR}/gtk-4.0/gtk.css
-  [[ ${color} != '-dark' ]] && \
-  cp -r ${SRC_DIR}/src/gtk/theme${theme}-4.0/gtk${win}-dark.css                      ${THEME_DIR}/gtk-4.0/gtk-dark.css
+
+  if [[ "$tweaks" == 'true' ]]; then
+    sassc $SASSC_OPT ${SRC_DIR}/src/gtk/theme-4.0/gtk${color}.scss                   ${THEME_DIR}/gtk-4.0/gtk.css
+  else
+    cp -r ${SRC_DIR}/src/gtk/theme-4.0/gtk${color}.css                               ${THEME_DIR}/gtk-4.0/gtk.css
+  fi
+
+  if [[ ${color} != '-dark' ]]; then
+    if [[ "$tweaks" == 'true' ]]; then
+      sassc $SASSC_OPT ${SRC_DIR}/src/gtk/theme-4.0/gtk-dark.scss                    ${THEME_DIR}/gtk-4.0/gtk-dark.css
+    else
+      cp -r ${SRC_DIR}/src/gtk/theme-4.0/gtk-dark.css                                ${THEME_DIR}/gtk-4.0/gtk-dark.css
+    fi
+  fi
+
   cp -r ${SRC_DIR}/src/gtk/assets/thumbnail${theme}${ELSE_DARK}.png                  ${THEME_DIR}/gtk-4.0/thumbnail.png
 
+ # GNOME SHELL
   mkdir -p                                                                           ${THEME_DIR}/gnome-shell
   cp -r ${SRC_DIR}/src/gnome-shell/common-assets                                     ${THEME_DIR}/gnome-shell/assets
-  cp -r ${SRC_DIR}/src/gnome-shell/assets${theme}/*.svg                              ${THEME_DIR}/gnome-shell/assets
+  cp -r ${SRC_DIR}/src/gnome-shell/assets${theme}/{background.jpg,calendar-today.svg} ${THEME_DIR}/gnome-shell/assets
   cp -r ${SRC_DIR}/src/gnome-shell/assets${theme}/assets${ELSE_DARK}/*.svg           ${THEME_DIR}/gnome-shell/assets
-  cp -r ${SRC_DIR}/src/gnome-shell/background.jpeg                                   ${THEME_DIR}/gnome-shell/background.jpeg
 
   if [[ -f ${SRC_DIR}/src/gnome-shell/logos/logo-${logo}.svg ]] ; then
     cp -r ${SRC_DIR}/src/gnome-shell/logos/logo-${logo}.svg                          ${THEME_DIR}/gnome-shell/assets/activities.svg
@@ -140,9 +188,17 @@ install() {
   cp -r ${SRC_DIR}/src/gnome-shell/pad-osd.css                                       ${THEME_DIR}/gnome-shell
 
   if [[ "${GS_VERSION:-}" == 'new' ]]; then
-    cp -r ${SRC_DIR}/src/gnome-shell/theme${theme}-40-0/gnome-shell${color}.css      ${THEME_DIR}/gnome-shell/gnome-shell.css
+    if [[ "$tweaks" == 'true' ]]; then
+      sassc $SASSC_OPT ${SRC_DIR}/src/gnome-shell/theme-40-0/gnome-shell${ELSE_DARK}.scss ${THEME_DIR}/gnome-shell/gnome-shell.css
+    else
+      cp -r ${SRC_DIR}/src/gnome-shell/theme-40-0/gnome-shell${ELSE_DARK}.css        ${THEME_DIR}/gnome-shell/gnome-shell.css
+    fi
   else
-    cp -r ${SRC_DIR}/src/gnome-shell/theme${theme}-3-32/gnome-shell${color}.css      ${THEME_DIR}/gnome-shell/gnome-shell.css
+    if [[ "$tweaks" == 'true' ]]; then
+      sassc $SASSC_OPT ${SRC_DIR}/src/gnome-shell/theme-3-32/gnome-shell${ELSE_DARK}.scss ${THEME_DIR}/gnome-shell/gnome-shell.css
+    else
+      cp -r ${SRC_DIR}/src/gnome-shell/theme-3-32/gnome-shell${ELSE_DARK}.css        ${THEME_DIR}/gnome-shell/gnome-shell.css
+    fi
   fi
 
   cd ${THEME_DIR}/gnome-shell
@@ -150,39 +206,68 @@ install() {
   ln -sf assets/process-working.svg process-working.svg
   ln -sf assets/no-notifications.svg no-notifications.svg
 
+  # CINNAMON
   mkdir -p                                                                           ${THEME_DIR}/cinnamon
   cp -r ${SRC_DIR}/src/cinnamon/assets${theme}/common-assets                         ${THEME_DIR}/cinnamon
   cp -r ${SRC_DIR}/src/cinnamon/assets${theme}/assets${ELSE_DARK}                    ${THEME_DIR}/cinnamon/assets
-  cp -r ${SRC_DIR}/src/cinnamon/theme${theme}/cinnamon${ELSE_DARK}.css               ${THEME_DIR}/cinnamon/cinnamon.css
+  if [[ "$tweaks" == 'true' ]]; then
+    sassc $SASSC_OPT ${SRC_DIR}/src/cinnamon/cinnamon${ELSE_DARK}.scss               ${THEME_DIR}/cinnamon/cinnamon.css
+  else
+    cp -r ${SRC_DIR}/src/cinnamon/cinnamon${ELSE_DARK}.css                           ${THEME_DIR}/cinnamon/cinnamon.css
+  fi
+
   cp -r ${SRC_DIR}/src/cinnamon/thumbnail${theme}${ELSE_DARK}.png                    ${THEME_DIR}/cinnamon/thumbnail.png
 
+  # METACITY
   mkdir -p                                                                           ${THEME_DIR}/metacity-1
-  cp -r ${SRC_DIR}/src/metacity-1/assets${ELSE_LIGHT}${win}/*.png                    ${THEME_DIR}/metacity-1
-  cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-3${win}.xml                         ${THEME_DIR}/metacity-1/metacity-theme-3.xml
-  cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-1${ELSE_LIGHT}${win}.xml            ${THEME_DIR}/metacity-1/metacity-theme-1.xml
+
+  if [[ "$window" == 'round' ]]; then
+    cp -r ${SRC_DIR}/src/metacity-1/assets-round                                     ${THEME_DIR}/metacity-1/assets
+    cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-3-round.xml                       ${THEME_DIR}/metacity-1/metacity-theme-3.xml
+    cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-1${ELSE_LIGHT}-round.xml          ${THEME_DIR}/metacity-1/metacity-theme-1.xml
+  else
+    if [[ "$square" == 'true' ]]; then
+      cp -r ${SRC_DIR}/src/metacity-1/assets${ELSE_LIGHT}-win/*.png                  ${THEME_DIR}/metacity-1
+      cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-3-win.xml                       ${THEME_DIR}/metacity-1/metacity-theme-3.xml
+      cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-1${ELSE_LIGHT}-win.xml          ${THEME_DIR}/metacity-1/metacity-theme-1.xml
+    else
+      cp -r ${SRC_DIR}/src/metacity-1/assets${ELSE_LIGHT}/*.png                      ${THEME_DIR}/metacity-1
+      cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-3.xml                           ${THEME_DIR}/metacity-1/metacity-theme-3.xml
+      cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-1${ELSE_LIGHT}.xml              ${THEME_DIR}/metacity-1/metacity-theme-1.xml
+    fi
+  fi
+
   cp -r ${SRC_DIR}/src/metacity-1/thumbnail${ELSE_LIGHT}.png                         ${THEME_DIR}/metacity-1/thumbnail.png
   cd ${THEME_DIR}/metacity-1
   ln -s metacity-theme-1.xml metacity-theme-2.xml
 
+  # XFWM4
   mkdir -p                                                                           ${THEME_DIR}/xfwm4
-  cp -r ${SRC_DIR}/src/xfwm4/themerc${win}${ELSE_LIGHT}                              ${THEME_DIR}/xfwm4/themerc
-  cp -r ${SRC_DIR}/src/xfwm4/assets${win}${ELSE_LIGHT}/*.png                         ${THEME_DIR}/xfwm4
 
+  if [[ "$square" == 'true' ]]; then
+    cp -r ${SRC_DIR}/src/xfwm4/themerc-win${ELSE_LIGHT}                              ${THEME_DIR}/xfwm4/themerc
+    cp -r ${SRC_DIR}/src/xfwm4/assets-win${ELSE_LIGHT}/*.png                         ${THEME_DIR}/xfwm4
+  else
+    cp -r ${SRC_DIR}/src/xfwm4/themerc${ELSE_LIGHT}                                  ${THEME_DIR}/xfwm4/themerc
+    cp -r ${SRC_DIR}/src/xfwm4/assets${ELSE_LIGHT}/*.png                             ${THEME_DIR}/xfwm4
+  fi
+
+  # OTHER
   cp -r ${SRC_DIR}/src/plank                                                         ${THEME_DIR}
   cp -r ${SRC_DIR}/src/unity                                                         ${THEME_DIR}
+  cp -r ${SRC_DIR}/src/xfce-notify-4.0                                               ${THEME_DIR}
 }
 
 # Backup and install files related to GDM theme
 
 GS_THEME_FILE="/usr/share/gnome-shell/gnome-shell-theme.gresource"
 SHELL_THEME_FOLDER="/usr/share/gnome-shell/theme"
-ETC_THEME_FOLDER="/etc/alternatives"
-ETC_THEME_FILE="/etc/alternatives/gdm3.css"
-UBUNTU_THEME_FILE="/usr/share/gnome-shell/theme/ubuntu.css"
-UBUNTU_NEW_THEME_FILE="/usr/share/gnome-shell/theme/gnome-shell.css"
+UBUNTU_THEME_FILE="/usr/share/gnome-shell/theme/Yaru/gnome-shell-theme.gresource"
+POP_OS_THEME_FILE="/usr/share/gnome-shell/theme/Pop/gnome-shell-theme.gresource"
+ZORIN_THEME_FILE="/usr/share/gnome-shell/theme/ZorinBlue-Light/gnome-shell-theme.gresource"
 
 install_gdm() {
-  local GDM_THEME_DIR="${1}/${2}${3}${4}${5}"
+  local GDM_THEME_DIR="${1}/${2}${3}${4}"
 
   if [[ -f "$GS_THEME_FILE" ]] && command -v glib-compile-resources >/dev/null ; then
     echo "Installing '$GS_THEME_FILE'..."
@@ -193,23 +278,22 @@ install_gdm() {
       "${SRC_DIR}/src/gnome-shell/gnome-shell-theme.gresource.xml"
   fi
 
-  if [[ -f "$UBUNTU_THEME_FILE" && -f "$GS_THEME_FILE.bak" ]]; then
+  if [[ -f "$UBUNTU_THEME_FILE" ]]; then
     echo "Installing '$UBUNTU_THEME_FILE'..."
     cp -an "$UBUNTU_THEME_FILE" "$UBUNTU_THEME_FILE.bak"
-    rm -rf "$GS_THEME_FILE"
-    mv "$GS_THEME_FILE.bak" "$GS_THEME_FILE"
-    cp -af "$GDM_THEME_DIR/gnome-shell/gnome-shell.css" "$UBUNTU_THEME_FILE"
+    cp -rf "$GS_THEME_FILE" "$UBUNTU_THEME_FILE"
   fi
 
-  if [[ -f "$ETC_THEME_FILE" && -f "$GS_THEME_FILE.bak" ]]; then
-    echo "Installing Ubuntu gnome-shell theme..."
-    cp -an "$ETC_THEME_FILE" "$ETC_THEME_FILE.bak"
-    rm -rf "$ETC_THEME_FILE" "$GS_THEME_FILE"
-    mv "$GS_THEME_FILE.bak" "$GS_THEME_FILE"
-    [[ -d $SHELL_THEME_FOLDER/$THEME_NAME ]] && rm -rf $SHELL_THEME_FOLDER/$THEME_NAME
-    cp -r "$GDM_THEME_DIR/gnome-shell" "$SHELL_THEME_FOLDER/$THEME_NAME"
-    cd "$ETC_THEME_FOLDER"
-    ln -s "$SHELL_THEME_FOLDER/$THEME_NAME/gnome-shell.css" gdm3.css
+  if [[ -f "$POP_OS_THEME_FILE" ]]; then
+    echo "Installing '$POP_OS_THEME_FILE'..."
+    cp -an "$POP_OS_THEME_FILE" "$POP_OS_THEME_FILE.bak"
+    cp -rf "$GS_THEME_FILE" "$POP_OS_THEME_FILE"
+  fi
+
+  if [[ -f "$ZORIN_THEME_FILE" ]]; then
+    echo "Installing '$ZORIN_THEME_FILE'..."
+    cp -an "$ZORIN_THEME_FILE" "$ZORIN_THEME_FILE.bak"
+    cp -rf "$GS_THEME_FILE" "$ZORIN_THEME_FILE"
   fi
 }
 
@@ -226,16 +310,142 @@ revert_gdm() {
     mv "$UBUNTU_THEME_FILE.bak" "$UBUNTU_THEME_FILE"
   fi
 
-  if [[ -f "$ETC_THEME_FILE.bak" ]]; then
-    echo "reverting Ubuntu gnome-shell theme..."
-    rm -rf "$ETC_THEME_FILE"
-    mv "$ETC_THEME_FILE.bak" "$ETC_THEME_FILE"
-    [[ -d $SHELL_THEME_FOLDER/$THEME_NAME ]] && rm -rf $SHELL_THEME_FOLDER/$THEME_NAME
+  if [[ -f "$POP_OS_THEME_FILE.bak" ]]; then
+    echo "reverting '$POP_OS_THEME_FILE'..."
+    rm -rf "$POP_OS_THEME_FILE"
+    mv "$POP_OS_THEME_FILE.bak" "$POP_OS_THEME_FILE"
+  fi
+
+  if [[ -f "$ZORIN_THEME_FILE.bak" ]]; then
+    echo "reverting '$ZORIN_THEME_FILE'..."
+    rm -rf "$ZORIN_THEME_FILE"
+    mv "$ZORIN_THEME_FILE.bak" "$ZORIN_THEME_FILE"
   fi
 }
 
-NBG_N="background-image: none;"
-NBG_I="@extend %nautilus_backimage;"
+while [[ $# -gt 0 ]]; do
+  case "${1}" in
+    -d|--dest)
+      dest="${2}"
+      if [[ ! -d "${dest}" ]]; then
+        echo "ERROR: Destination directory does not exist."
+        exit 1
+      fi
+      shift 2
+      ;;
+    -n|--name)
+      name="${2}"
+      shift 2
+      ;;
+    -l|--logo)
+      logo="${2}"
+      shift 2
+      ;;
+    -g|--gdm)
+      gdm='true'
+      shift
+      ;;
+    -r|--revert)
+      revert='true'
+      shift
+      ;;
+    -t|--theme)
+      accent='true'
+      shift
+      for theme in "${@}"; do
+        case "${theme}" in
+          default)
+            themes+=("${THEME_VARIANTS[0]}")
+            shift 1
+            ;;
+          manjaro)
+            themes+=("${THEME_VARIANTS[1]}")
+            shift 1
+            ;;
+          ubuntu)
+            themes+=("${THEME_VARIANTS[2]}")
+            shift 1
+            ;;
+          all)
+            themes+=("${THEME_VARIANTS[@]}")
+            shift 1
+            ;;
+          -*|--*)
+            break
+            ;;
+          *)
+            echo "ERROR: Unrecognized theme variant '$1'."
+            echo "Try '$0 --help' for more information."
+            exit 1
+            ;;
+        esac
+      done
+      ;;
+    -c|--color)
+      shift
+      for color in "${@}"; do
+        case "${color}" in
+          standard)
+            colors+=("${COLOR_VARIANTS[0]}")
+            shift 1
+            ;;
+          light)
+            colors+=("${COLOR_VARIANTS[1]}")
+            shift 1
+            ;;
+          dark)
+            colors+=("${COLOR_VARIANTS[2]}")
+            shift 1
+            ;;
+          -*|--*)
+            break
+            ;;
+          *)
+            echo "ERROR: Unrecognized color variant '$1'."
+            echo "Try '$0 --help' for more information."
+            exit 1
+            ;;
+        esac
+      done
+      ;;
+    --tweaks)
+      shift
+      for tweak in "${@}"; do
+        case "${tweak}" in
+          image)
+            image='true'
+            shift
+            ;;
+          round)
+            window='round'
+            shift
+            ;;
+          square)
+            square='true'
+            shift
+            ;;
+          -*|--*)
+            break
+            ;;
+          *)
+            echo "ERROR: Unrecognized tweak variant '$1'."
+            echo "Try '$0 --help' for more information."
+            exit 1
+            ;;
+        esac
+      done
+      ;;
+    -h|--help)
+      usage
+      exit 0
+      ;;
+    *)
+      echo "ERROR: Unrecognized installation option '$1'."
+      echo "Try '$0 --help' for more information."
+      exit 1
+      ;;
+  esac
+done
 
 # check command avalibility
 function has_command() {
@@ -305,158 +515,71 @@ install_package() {
   fi
 }
 
-parse_sass() {
-  cd ${SRC_DIR} && ./parse-sass.sh
-}
-
 install_theme() {
-  for theme in "${themes[@]-${THEME_VARIANTS[@]}}"; do
-    for win in "${wins[@]-${WIN_VARIANTS[@]}}"; do
-      for color in "${colors[@]-${COLOR_VARIANTS[@]}}"; do
-          install "${dest:-${DEST_DIR}}" "${name:-${THEME_NAME}}" "${theme}" "${win}" "${color}" "${logo:-${LOGO_NAME}}"
-      done
+  for theme in "${themes[@]-${THEME_VARIANTS[0]}}"; do
+    for color in "${colors[@]-${COLOR_VARIANTS[@]}}"; do
+      install "${dest:-${DEST_DIR}}" "${name:-${THEME_NAME}}" "${theme}" "${color}" "${logo:-${LOGO_NAME}}"
     done
   done
 }
 
-install_img() {
-  cd ${SRC_DIR}/src/_sass/gtk/apps
-  cp -an _gnome.scss _gnome.scss.bak
-  sed -i "s/$NBG_N/$NBG_I/g" _gnome.scss
-  echo -e "Specify theme with nautilus background image ..."
+tweaks_temp() {
+  cp -rf ${SRC_DIR}/src/_sass/_tweaks.scss ${SRC_DIR}/src/_sass/_tweaks-temp.scss
 }
 
-restore_img() {
-  cd ${SRC_DIR}/src/_sass/gtk/apps
-  [[ -f _gnome.scss.bak ]] && rm -rf _gnome.scss
-  mv _gnome.scss.bak _gnome.scss
-  echo -e "Restore scss files ..."
+install_image() {
+  sed -i "/\$background:/s/default/image/" ${SRC_DIR}/src/_sass/_tweaks-temp.scss
+  echo -e "Install Nautilus with background image version ..."
 }
 
-while [[ $# -gt 0 ]]; do
-  case "${1}" in
-    -d|--dest)
-      dest="${2}"
-      if [[ ! -d "${dest}" ]]; then
-        echo "ERROR: Destination directory does not exist."
-        exit 1
-      fi
-      shift 2
-      ;;
-    -n|--name)
-      name="${2}"
-      shift 2
-      ;;
-    -l|--logo)
-      logo="${2}"
-      shift 2
-      ;;
-    -g|--gdm)
-      gdm='true'
-      shift
-      ;;
-    -r|--revert)
-      revert='true'
-      shift
-      ;;
-    -i|--image)
-      image='true'
-      shift
-      ;;
-    -w|--win)
-      shift
-      for win in "${@}"; do
-        case "${win}" in
-          standard)
-            wins+=("${WIN_VARIANTS[0]}")
-            shift 1
-            ;;
-          square)
-            wins+=("${WIN_VARIANTS[1]}")
-            shift 1
-            ;;
-          -*|--*)
-            break
-            ;;
-          *)
-            echo "ERROR: Unrecognized color variant '$1'."
-            echo "Try '$0 --help' for more information."
-            exit 1
-            ;;
-        esac
-      done
-      ;;
-    -t|--theme)
-      shift
-      for theme in "${@}"; do
-        case "${theme}" in
-          standard)
-            themes+=("${THEME_VARIANTS[0]}")
-            shift 1
-            ;;
-          manjaro)
-            themes+=("${THEME_VARIANTS[1]}")
-            shift 1
-            ;;
-          ubuntu)
-            themes+=("${THEME_VARIANTS[2]}")
-            shift 1
-            ;;
-          -*|--*)
-            break
-            ;;
-          *)
-            echo "ERROR: Unrecognized color variant '$1'."
-            echo "Try '$0 --help' for more information."
-            exit 1
-            ;;
-        esac
-      done
-      ;;
-    -c|--color)
-      shift
-      for color in "${@}"; do
-        case "${color}" in
-          standard)
-            colors+=("${COLOR_VARIANTS[0]}")
-            shift 1
-            ;;
-          light)
-            colors+=("${COLOR_VARIANTS[1]}")
-            shift 1
-            ;;
-          dark)
-            colors+=("${COLOR_VARIANTS[2]}")
-            shift 1
-            ;;
-          -*|--*)
-            break
-            ;;
-          *)
-            echo "ERROR: Unrecognized color variant '$1'."
-            echo "Try '$0 --help' for more information."
-            exit 1
-            ;;
-        esac
-      done
-      ;;
-    -h|--help)
-      usage
-      exit 0
-      ;;
-    *)
-      echo "ERROR: Unrecognized installation option '$1'."
-      echo "Try '$0 --help' for more information."
-      exit 1
-      ;;
-  esac
-done
+install_win_titlebutton() {
+  sed -i "/\$titlebutton:/s/circle/square/" ${SRC_DIR}/src/_sass/_tweaks-temp.scss
+  echo -e "Install Square titlebutton version ..."
+}
 
-if [[ "${gdm:-}" != 'true' && "${revert:-}" != 'true' && "${image:-}" != 'true' ]]; then
+install_round_window() {
+  sed -i "/\$window:/s/default/round/" ${SRC_DIR}/src/_sass/_tweaks-temp.scss
+  echo -e "Install Round window version ..."
+}
+
+install_theme_color() {
+  if [[ "$theme" != '' ]]; then
+    case "$theme" in
+      -manjaro)
+        theme_color='manjaro'
+        ;;
+      -ubuntu)
+        theme_color='ubuntu'
+        ;;
+    esac
+    sed -i "/\$theme:/s/default/${theme_color}/" ${SRC_DIR}/src/_sass/_tweaks-temp.scss
+  fi
+}
+
+theme_tweaks() {
+  if [[ "$image" == "true" || "$square" == "true" || "$accent" == 'true' || "$window" == 'round' ]]; then
+    tweaks='true'
+    install_package; tweaks_temp
+  fi
+
+  if [[ "$image" == "true" ]] ; then
+    install_image
+  fi
+
+  if [[ "$square" == "true" ]] ; then
+    install_win_titlebutton
+  fi
+
+  if [[ "$window" == "round" ]] ; then
+    install_round_window
+  fi
+}
+
+if [[ "${gdm:-}" != 'true' && "${revert:-}" != 'true' ]]; then
   install_theme
 fi
 
-if [[ "${gdm:-}" == 'true' && "${revert:-}" != 'true' && "${image:-}" != 'true' && "$UID" -eq "$ROOT_UID" ]]; then
+if [[ "${gdm:-}" == 'true' && "${revert:-}" != 'true' && "$UID" -eq "$ROOT_UID" ]]; then
   install_theme && install_gdm "${dest:-${DEST_DIR}}" "${name:-${THEME_NAME}}" "${theme}" "${color}"
 fi
 
@@ -464,13 +587,5 @@ if [[ "${gdm:-}" != 'true' && "${revert:-}" == 'true' && "$UID" -eq "$ROOT_UID"
   revert_gdm
 fi
 
-if [[ "${gdm:-}" != 'true' && "${image:-}" == 'true'  ]]; then
-  install_package && install_img && parse_sass && install_theme && restore_img && parse_sass
-fi
-
-if [[ "${gdm:-}" == 'true' && "${revert:-}" != 'true' && "${image:-}" == 'true' && "$UID" -eq "$ROOT_UID" ]]; then
-  install_package && install_img && parse_sass && install_theme && restore_img && parse_sass && install_gdm
-fi
-
 echo
 echo Done.
